==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DepozytPKonto.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DepozytPKonto extends GenericDPSObject {
    /**
     * DEPOZYT_P_KONTO.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DEPOZYT_P_KONTO.KONTO_BANKOWE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kontoBankoweId;

    /**
     * DEPOZYT_P_KONTO.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * DEPOZYT_P_KONTO.ZAMKNIETE
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean zamkniete;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_KONTO.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_KONTO.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_KONTO.KONTO_BANKOWE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKontoBankoweId() {
        return kontoBankoweId;
    }

    /**
     * DEPOZYT_P_KONTO.KONTO_BANKOWE_ID
     *
     * @param kontoBankoweId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKontoBankoweId(Long kontoBankoweId) {
        this.kontoBankoweId = kontoBankoweId;
    }

    /**
     * @return DEPOZYT_P_KONTO.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DEPOZYT_P_KONTO.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DEPOZYT_P_KONTO.ZAMKNIETE
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getZamkniete() {
        return zamkniete;
    }

    /**
     * DEPOZYT_P_KONTO.ZAMKNIETE
     *
     * @param zamkniete
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZamkniete(Boolean zamkniete) {
        this.zamkniete = zamkniete;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPKonto other = (DepozytPKonto) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getKontoBankoweId() == null ? other.getKontoBankoweId() == null : this.getKontoBankoweId().equals(other.getKontoBankoweId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getZamkniete() == null ? other.getZamkniete() == null : this.getZamkniete().equals(other.getZamkniete()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getKontoBankoweId() == null) ? 0 : getKontoBankoweId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getZamkniete() == null) ? 0 : getZamkniete().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", kontoBankoweId=").append(kontoBankoweId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", zamkniete=").append(zamkniete);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DepozytPKonto.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DepozytPKonto extends GenericDPSObject {
    /**
     * DEPOZYT_P_KONTO.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DEPOZYT_P_KONTO.KONTO_BANKOWE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kontoBankoweId;

    /**
     * DEPOZYT_P_KONTO.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * DEPOZYT_P_KONTO.ZAMKNIETE
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean zamkniete;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_KONTO.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_KONTO.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_KONTO.KONTO_BANKOWE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKontoBankoweId() {
        return kontoBankoweId;
    }

    /**
     * DEPOZYT_P_KONTO.KONTO_BANKOWE_ID
     *
     * @param kontoBankoweId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKontoBankoweId(Long kontoBankoweId) {
        this.kontoBankoweId = kontoBankoweId;
    }

    /**
     * @return DEPOZYT_P_KONTO.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * DEPOZYT_P_KONTO.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return DEPOZYT_P_KONTO.ZAMKNIETE
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getZamkniete() {
        return zamkniete;
    }

    /**
     * DEPOZYT_P_KONTO.ZAMKNIETE
     *
     * @param zamkniete
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZamkniete(Boolean zamkniete) {
        this.zamkniete = zamkniete;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPKonto other = (DepozytPKonto) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getKontoBankoweId() == null ? other.getKontoBankoweId() == null : this.getKontoBankoweId().equals(other.getKontoBankoweId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getZamkniete() == null ? other.getZamkniete() == null : this.getZamkniete().equals(other.getZamkniete()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getKontoBankoweId() == null) ? 0 : getKontoBankoweId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getZamkniete() == null) ? 0 : getZamkniete().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", kontoBankoweId=").append(kontoBankoweId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", zamkniete=").append(zamkniete);
        sb.append("]");
        return sb.toString();
    }
}
